import { s3 } from '$lib/storage.server';
import { error, json } from '@sveltejs/kit';
import type { RequestHandler } from './$types';
import { ListObjectsV2Command } from '@aws-sdk/client-s3';
import { env } from '$env/dynamic/private';

export const GET: RequestHandler = async ({ url }) => {
    const pubkeyHex = url.searchParams.get('pubkey')?.trim()?.toLowerCase();
    if (!pubkeyHex || !/^[0-9a-f]{64}$/.test(pubkeyHex)) error(400);

    const objects = [];

    let continuationToken: string | undefined;
    do {
        const command = new ListObjectsV2Command({
            Bucket: env.S3_BUCKET,
            Prefix: `${pubkeyHex}/`,
            ContinuationToken: continuationToken,
        });


        const res = await s3.send(command);
        objects.push(...(res.Contents ?? []));

        continuationToken = res.NextContinuationToken;
    } while (continuationToken);

    return json(objects.filter(obj => !!obj.Key).map(obj => {
        return {
            date: obj.Key!.split('/').at(-1),
            url: `https://${env.S3_BUCKET}.${env.S3_HOST}/${encodeURIComponent(obj.Key!)}`
        };
    }));
}
