import { convertVideo } from "$lib/ffmpeg.server";
import { error, json, text } from "@sveltejs/kit";
import type { RequestHandler } from "./$types";
import { PutObjectCommand } from "@aws-sdk/client-s3";
import { env } from "$env/dynamic/private";
import { s3 } from "$lib/storage.server";

export const POST: RequestHandler = async ({ request, url }) => {
    const pubkeyHex = url.searchParams.get('pubkey')?.trim()?.toLowerCase();
    if (!pubkeyHex || !/^[0-9a-f]{64}$/.test(pubkeyHex)) error(400);

    const today = new Date().toISOString().slice(0, 10);

    const bodyBuffer = await request.arrayBuffer();
    const bodyUint8 = new Uint8Array(bodyBuffer);

    console.log(today, bodyUint8.byteLength);

    const command = new PutObjectCommand({
        Bucket: env.S3_BUCKET,
        Key: `${pubkeyHex}/${today}`,
        Body: bodyUint8,
        ContentType: 'application/octet-stream',
    });

    await s3.send(command);

    return text('ok');
}
